/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'image', 'ro', {
	alt: 'Text alternativ',
	border: 'Margine',
	btnUpload: 'Trimite la server',
	button2Img: 'Buton imagine în imagine normală',
	hSpace: 'HSpace',
	img2Button: 'Imagine în buton imagine',
	infoTab: 'Informaţii despre imagine',
	linkTab: 'Link (Legătură web)',
	lockRatio: 'Păstrează proporţiile',
	menu: 'Proprietăţile imaginii',
	resetSize: 'Resetează mărimea',
	title: 'Proprietăţile imaginii',
	titleButton: 'Proprietăţi buton imagine (Image Button)',
	upload: 'Încarcă',
	urlMissing: 'Sursa URL a imaginii lipsește.',
	vSpace: 'VSpace',
	validateBorder: 'Bordura trebuie să fie număr întreg.',
	validateHSpace: 'Hspace trebuie să fie număr întreg.',
	validateVSpace: 'Vspace trebuie să fie număr întreg.'
} );
